@@ -3,9 +3,9 @@
  * IMP_Quota:: provides an API for retrieving Quota details from a mail
  * server.
  *
- * $Horde: imp/lib/Quota.php,v 1.23.10.5 2005/07/03 03:42:43 selsky Exp $
+ * $Horde: imp/lib/Quota.php,v 1.23.10.8 2006/01/01 21:28:55 jan Exp $
  *
- * Copyright 2002-2005 Mike Cochrane <mike@graftonhall.co.nz>
+ * Copyright 2002-2006 Mike Cochrane <mike@graftonhall.co.nz>
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
@@ -39,10 +39,12 @@ class IMP_Quota {
         require_once dirname(__FILE__) . '/Quota/' . $driver . '.php';
         $class = 'IMP_Quota_' . $driver;
         if (class_exists($class)) {
-            return $ret = &new $class($params);
+            $quota = &new $class($params);
         } else {
-            return false;
+            $quota = false;
         }
+
+        return $quota;
     }
 
     /**
