@@ -1,9 +1,9 @@
 <?php
 /**
- * $Horde: imp/redirect.php,v 1.116.2.6 2005/09/01 12:06:54 jan Exp $
+ * $Horde: imp/redirect.php,v 1.116.2.13 2006/04/23 03:08:53 chuck Exp $
  *
- * Copyright 1999-2005 Charles J. Hagenbuch <chuck@horde.org>
- * Copyright 1999-2005 Jon Parise <jon@horde.org>
+ * Copyright 1999-2006 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2006 Jon Parise <jon@horde.org>
  *
  * See the enclosed file COPYING for license information (GPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
@@ -29,10 +29,10 @@ function _newSessionUrl($actionID, $isLogin)
         /* Force the initial page to IMP if we're logging in to compose a
          * message. */
         if ($actionID == 'login_compose') {
-            $url = Util::addParameter($url, 'url', IMP::getInitialUrl('login_compose', false));
+            $url = Util::addParameter($url, 'url', IMP_Session::getInitialUrl('login_compose', false));
         }
     } else {
-        $url = IMP::getInitialUrl($actionID, false);
+        $url = IMP_Session::getInitialUrl($actionID, false);
         if ($isLogin) {
             /* Don't show popup window in initial page. */
             $url = Util::addParameter($url, 'no_newmail_popup', 1, false);
@@ -64,6 +64,7 @@ function _redirect($url)
 $authentication = 'none';
 require_once IMP_BASE . '/lib/base.php';
 require_once IMP_BASE . '/lib/Session.php';
+require_once 'Horde/Maintenance.php';
 
 $actionID = (Util::getFormData('action') == 'compose') ? 'login_compose' : Util::getFormData('actionID');
 $autologin = Util::getFormData('autologin');
@@ -72,43 +73,41 @@ $pass = empty($autologin) ? Util::getPost('pass') : Auth::getCredential('passwor
 $isLogin = IMP::loginTasksFlag();
 
 /* If we are returning from Maintenance processing. */
-if (!$isLogin) {
-    require_once 'Horde/Maintenance.php';
-    if (Util::getFormData(MAINTENANCE_DONE_PARAM)) {
-        /* Finish up any login tasks we haven't completed yet. */
-        IMP_Session::loginTasks();
+if (Util::getFormData(MAINTENANCE_DONE_PARAM)) {
+    /* Finish up any login tasks we haven't completed yet. */
+    IMP_Session::loginTasks();
 
-        _redirect(_framesetUrl(_newSessionUrl($actionID, $isLogin)));
-    }
+    _redirect(_framesetUrl(_newSessionUrl($actionID, $isLogin)));
 }
 
 /* If we already have a session: */
 if (isset($_SESSION['imp']) && is_array($_SESSION['imp'])) {
     /* Make sure that if a username was specified, it is the current
      * username. */
-    if ((is_null($imapuser) || ($imapuser == $_SESSION['imp']['user'])) &&
-        (is_null($pass) || ($pass == Secret::read(Secret::getKey('imp'), $_SESSION['imp']['pass'])))) {
+    if (($imapuser !== null && ($imapuser != $_SESSION['imp']['user'])) ||
+        ($pass !== null && ($pass != Secret::read(Secret::getKey('imp'), $_SESSION['imp']['pass'])))) {
 
-        IMP_Session::loginTasks();
-
-        $url = Util::getFormData('url');
-        if (empty($url)) {
-            $url = IMP::getInitialUrl($actionID, false);
-        } elseif (!empty($actionID)) {
-            $url = Util::addParameter($url, 'actionID', $actionID, false);
-        }
-
-        /* Don't show popup window in initial page. */
-        if ($isLogin) {
-            $url = Util::addParameter($url, 'no_newmail_popup', 1, false);
-        }
-
-        _redirect(_framesetUrl($url));
-    } else {
         /* Disable the old session. */
         unset($_SESSION['imp']);
         _redirect(Auth::addLogoutParameters(IMP::logoutUrl(), AUTH_REASON_FAILED));
     }
+
+    /* Finish up any login tasks we haven't completed yet. */
+    IMP_Session::loginTasks();
+
+    $url = Util::getFormData('url');
+    if (empty($url)) {
+        $url = IMP_Session::getInitialUrl($actionID, false);
+    } elseif (!empty($actionID)) {
+        $url = Util::addParameter($url, 'actionID', $actionID, false);
+    }
+
+    /* Don't show popup window in initial page. */
+    if ($isLogin) {
+        $url = Util::addParameter($url, 'no_newmail_popup', 1, false);
+    }
+
+    _redirect(_framesetUrl($url));
 }
 
 /* Create a new session if we're given the proper parameters. */
@@ -127,17 +126,20 @@ if ((!is_null($imapuser) && !is_null($pass))) {
         $sessArray = $servers[$server_key];
     }
 
+    /* If we're not using hordeauth get parameters altered from the defaults
+     * from the form data. */
     if (empty($autologin)) {
-        foreach (array('server', 'port', 'protocol', 'folders') as $val) {
+        foreach (array('server', 'port', 'protocol', 'folders', 'smtphost', 'smtpport') as $val) {
             $data = Util::getFormData($val);
             if (!empty($data)) {
                 $sessArray[$val] = $data;
             }
         }
     } else {
-        if (!empty($sessArray['hordeauth']) &&
-            strcasecmp($sessArray['hordeauth'], 'full') == 0) {
-            $imapuser = Auth::getAuth();
+        if (!empty($sessArray['hordeauth'])) {
+            if (strcasecmp($sessArray['hordeauth'], 'full') == 0) {
+                $imapuser = Auth::getAuth();
+            }
         } else {
             $entry = sprintf('Invalid server key "%s" from client [%s]', $server_key, $_SERVER['REMOTE_ADDR']);
             Horde::logMessage($entry, __FILE__, __LINE__, PEAR_LOG_INFO);
@@ -165,9 +167,7 @@ if ((!is_null($imapuser) && !is_null($pass))) {
         $url = Auth::addLogoutParameters(IMP::logoutUrl());
     }
 
-    $url = _framesetUrl($url);
-
-    _redirect($url);
+    _redirect(_framesetUrl($url));
 }
 
 /* No session, and no login attempt. Just go to the login page. */
